@@ -14,11 +14,13 @@ class RCDB:
     ZIP = 'zip'
     CLASSIFICATION_DATABASE = 'rcdb'
     VIRTUAL_CLASSIFICATION_DATABASE = 'vrcdb'
+    JSON = 'json'
 
     EXTENSION_CHOICES = (
         (ZIP, 'zip archive'),
         (CLASSIFICATION_DATABASE, 'Rebotics database format'),
         (VIRTUAL_CLASSIFICATION_DATABASE, 'Rebotics virtual database format'),
+        (JSON, "Flat json of image urls and labels"),
     )
 
     FEATURE_VECTORS = 'feature_vectors'
