@@ -289,13 +289,14 @@ class ReboticsBaseProvider(object):
                ('x-retailer-secret-key' in header_keys)
 
 
-class PageResult(object):
+class PageResult(dict):
     def __init__(self, json_data):
         """
         Returns paged result from rest framework
         :param dict json_data:
         """
         self.json_data = json_data
+        super(PageResult, self).__init__(json_data)
 
     def __len__(self):
         return self.json_data['count']
